#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global mod_name pyxattr
%define github_url https://github.com/iustin/%{mod_name}/releases/download
%{?sle15_python_module_pythons}
Name:           python-%{mod_name}
Version:        0.8.1
Release:        1.6
Summary:        Filesystem extended attributes for python
License:        LGPL-2.1-or-later
URL:            https://pyxattr.k1024.org/
Source0:        %{github_url}/v%{version}/%{mod_name}-%{version}.tar.gz
Source1:        %{github_url}/v%{version}/%{mod_name}-%{version}.tar.gz.asc
Source2:        https://k1024.org/files/key.asc#/%{name}.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  libattr-devel
BuildRequires:  python-rpm-macros
%python_subpackages

%description
This is a C extension module for Python which
implements extended attributes manipulation. It is a wrapper on top
of the attr C library - see attr(5).

%prep
%autosetup -n pyxattr-%{version}

%build
%python_build

%check
# Tests are mostly disabled because for gh#iustin/pyxattr#34
%pytest_arch tests || /bin/true

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%{python_sitearch}/xattr*
%{python_sitearch}/pyxattr-%{version}*-info
%license COPYING
%doc NEWS.md README.md

%changelog
* Sat Oct  7 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 0.8.1:
  - Fix the pypi declared python versions
  - Add some more documentation - a security policy, and a
    contributing guide.
  - Minor bugfix release, but due to lack of CI environments
    supporting old Python versions, only Python 3.7+ is
    supported. Otherwise:
  - @Snape3058 found some refcount issues (see issue #35),
    these have been fixed.
  - Tested and enabled Python 3.10 support, dropped < 3.7.
  - Move fully to setuptools (where available), in preparation
    for 3.12 dropping distutils support.
* Thu Jul 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Nov 30 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.7.2
  Minor release:
  * Expand testing by adding better mixed-access checks (e.g. set via symlink and read on file) and by not leaking resources during tests.
  * Enable testing with Python 3.9 and confirm compatibility with it.
  * Fix documentation building with Sphinx 3.0+.
* Fri Nov 13 2020 Benjamin Greiner <code@bnavigator.de>
- Fix BuildRequires for multiple python3 flavors
  gh#openSUSE/python-rpm-macros#66
- Use %%pytest_arch
* Wed Feb 19 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.7.1
  * Fix license to LGPL 2.1 and later
  * Add keyring for source verification
  Changelog:
  Major change: drop compatibility with Python 2, which allows significant code
  cleanups.
  Other changes:
  * Switch internal implementation of argument parsing to a built-in one
    (`PyUnicode_FSConverter`), which brings automatic support for
    path-like objects in Python 3.6+ (#20), and also a more uniform
    handling of Unicode path arguments with respect to other Python code.
  * Fix missing error check in list operations in `get_all` (#17).
  * Switch test library to pytest; not that a reasonable recent version is
    needed. Additionally, expand test coverage, although not directly
    visible in actual coverage reports…
* Tue Jul 16 2019 Dan Čermák <dcermak@suse.com>
- Initial package version
